@@ -3,15 +3,13 @@ package Dist::Zilla::PluginBundle::Author::OpusVL::ToCPAN;
 use Moose;
 use 5.014;
 
-use Dist::Zilla::PluginBundle::Filter;
-use Dist::Zilla::PluginBundle::Author::OpusVL;
 with (
     'Dist::Zilla::Role::PluginBundle::Easy',
     'Dist::Zilla::Role::PluginBundle::PluginRemover',
     'Dist::Zilla::Role::PluginBundle::Config::Slicer',
 );
 
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 
 sub configure {
     my $self = shift;
